@@ -1358,7 +1358,7 @@ hipError_t hipMalloc3DArray(hipArray_t *array,
|
|||||||
* @see hipMemcpy, hipMemcpyToArray, hipMemcpy2DToArray, hipMemcpyFromArray, hipMemcpyToSymbol, hipMemcpyAsync
|
* @see hipMemcpy, hipMemcpyToArray, hipMemcpy2DToArray, hipMemcpyFromArray, hipMemcpyToSymbol, hipMemcpyAsync
|
||||||
*/
|
*/
|
||||||
hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, hipMemcpyKind kind);
|
hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, hipMemcpyKind kind);
|
||||||
hipError_t hipMemcpy_2D(const hip_Memcpy2D* pCopy);
|
hipError_t hipMemcpyParam2D(const hip_Memcpy2D* pCopy);
|
||||||
|
|
||||||
/**
|
/**
|
||||||
* @brief Copies data between host and device.
|
* @brief Copies data between host and device.
|
||||||
|
|||||||
@@ -70,7 +70,7 @@ bool runTest(int argc, char **argv)
|
|||||||
copyParam.srcPitch = width * sizeof(float);
|
copyParam.srcPitch = width * sizeof(float);
|
||||||
copyParam.widthInBytes = copyParam.srcPitch;
|
copyParam.widthInBytes = copyParam.srcPitch;
|
||||||
copyParam.height = height;
|
copyParam.height = height;
|
||||||
hipMemcpy_2D(©Param);
|
hipMemcpyParam2D(©Param);
|
||||||
|
|
||||||
textureReference* texref;
|
textureReference* texref;
|
||||||
hipModuleGetTexRef(&texref, Module, "tex");
|
hipModuleGetTexRef(&texref, Module, "tex");
|
||||||
|
|||||||
@@ -1134,7 +1134,7 @@ hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch,
|
|||||||
return ihipLogStatus(e);
|
return ihipLogStatus(e);
|
||||||
}
|
}
|
||||||
|
|
||||||
hipError_t hipMemcpy_2D(const hip_Memcpy2D* pCopy)
|
hipError_t hipMemcpyParam2D(const hip_Memcpy2D* pCopy)
|
||||||
{
|
{
|
||||||
HIP_INIT_SPECIAL_API((TRACE_MCMD), pCopy);
|
HIP_INIT_SPECIAL_API((TRACE_MCMD), pCopy);
|
||||||
hipError_t e = hipSuccess;
|
hipError_t e = hipSuccess;
|
||||||
|
|||||||
新しいイシューから参照
ユーザーをブロックする